@@ -41,9 +41,9 @@ if not settings.mpv_ext:
         # noinspection PyPackageRequirements
         import mpv
 
-        log.info("Using libmpv1 playback backend.")
+        log.info("Using libmpv playback backend.")
     except OSError:
-        log.warning("Could not find libmpv1.")
+        log.warning("Could not find libmpv.")
         python_mpv_available = False
 
 if settings.mpv_ext or not python_mpv_available:
@@ -202,6 +202,13 @@ class PlayerManager(object):
             mpv_options["config"] = True
             mpv_options["config_dir"] = conffile.confdir(APP_NAME)
 
+        if settings.tls_client_cert and settings.tls_client_key:
+            mpv_options['tls_cert_file'] = settings.tls_client_cert
+            mpv_options['tls_key_file'] = settings.tls_client_key
+
+            if settings.tls_server_ca:
+                mpv_options['tls_ca_file'] = settings.tls_server_ca
+
         self._player = mpv.MPV(
             input_default_bindings=True,
             input_vo_keyboard=True,
@@ -210,11 +217,15 @@ class PlayerManager(object):
             loglevel=settings.mpv_log_level,
             **mpv_options,
         )
+
         self.menu = OSDMenu(self, self._player)
         self.syncplay = SyncPlayManager(self)
 
         if discord_presence:
-            register_join_event(self.syncplay.discord_join_group)
+            try:
+                register_join_event(self.syncplay.discord_join_group)
+            except Exception:
+                log.error("Could not register Discord join callback.", exc_info=True)
 
         if hasattr(self._player, "osc"):
             self.enable_osc(settings.enable_osc)
@@ -395,7 +406,7 @@ class PlayerManager(object):
                 ):
                     self.syncplay.seek_request(play_time)
                 else:
-                    log.debug("SyncPlay Buffering: {0}".format(value))
+                    log.info("SyncPlay Buffering: {0}".format(value))
                     if value:
                         self.syncplay.on_buffer()
                     else:
@@ -472,9 +483,9 @@ class PlayerManager(object):
         if (
             (
                 settings.skip_intro_always
-                or settings.skip_intro_prompt
+                or settings.skip_intro_enable
                 or settings.skip_credits_always
-                or settings.skip_credits_prompt
+                or settings.skip_credits_enable
             )
             and not self.syncplay.is_enabled()
             and self._video is not None
@@ -486,11 +497,11 @@ class PlayerManager(object):
 
             if intro is not None:
                 should_prompt = (
-                    intro.type != "Credits" and settings.skip_intro_prompt
-                ) or (intro.type == "Credits" and settings.skip_credits_prompt)
+                    intro.type != "Outro" and settings.skip_intro_enable
+                ) or (intro.type == "Outro" and settings.skip_credits_enable)
                 should_skip = (not intro.has_triggered) and (
-                    (intro.type != "Credits" and settings.skip_intro_always)
-                    or (intro.type == "Credits" and settings.skip_credits_always)
+                    (intro.type != "Outro" and settings.skip_intro_always)
+                    or (intro.type == "Outro" and settings.skip_credits_always)
                 )
 
                 if should_skip and ready_to_skip:
@@ -498,7 +509,7 @@ class PlayerManager(object):
                     self.skip_intro()
                     self._player.show_text(
                         _("Skipped Credits")
-                        if intro.type == "Credits"
+                        if intro.type == "Outro"
                         else _("Skipped Intro"),
                         3000,
                         1,
@@ -507,7 +518,7 @@ class PlayerManager(object):
                 if not self.is_in_intro and should_prompt:
                     self._player.show_text(
                         _("Seek to Skip Credits")
-                        if intro.type == "Credits"
+                        if intro.type == "Outro"
                         else _("Seek to Skip Intro"),
                         3000,
                         1,
@@ -557,7 +568,7 @@ class PlayerManager(object):
             self.trickplay.clear()
 
         if settings.log_decisions:
-            log.debug("Playing: {0}".format(url))
+            log.info("Playing: {0}".format(url))
         if self.get_webview() is not None and settings.display_mirroring:
             # noinspection PyUnresolvedReferences
             self.get_webview().hide()
@@ -570,7 +581,7 @@ class PlayerManager(object):
             log.error("Timeout when waiting for media duration. Stopping playback!")
             self.stop()
             return
-        log.debug("Finished waiting for media duration.")
+        log.info("Finished waiting for media duration.")
         if settings.fullscreen and not self.fullscreen_disable:
             self._player.fs = True
         self._player.force_media_title = video.get_proper_title()
@@ -640,7 +651,7 @@ class PlayerManager(object):
             self.exec_stop_cmd()
             return
 
-        log.debug("PlayerManager::stop stopping playback of %s" % self._video)
+        log.info("PlayerManager::stop stopping playback of %s" % self._video)
 
         self.should_send_timeline = False
         options = self.get_timeline_options()
@@ -755,7 +766,7 @@ class PlayerManager(object):
             self._video.set_played()
         if self._video.parent.has_next and settings.auto_play:
             if has_lock:
-                log.debug("PlayerManager::finished_callback starting next episode")
+                log.info("PlayerManager::finished_callback starting next episode")
                 new_video = self._video.parent.get_next().video
                 self.send_timeline_stopped(True)
                 if self.syncplay.is_enabled():
@@ -763,7 +774,7 @@ class PlayerManager(object):
                 else:
                     self.play(new_video)
             else:
-                log.debug("PlayerManager::finished_callback No lock, skipping...")
+                log.info("PlayerManager::finished_callback No lock, skipping...")
         else:
             if settings.media_ended_cmd:
                 os.system(settings.media_ended_cmd)
@@ -771,7 +782,7 @@ class PlayerManager(object):
             if self.syncplay.is_enabled():
                 self.syncplay.disable_sync_play(False)
 
-            log.debug("PlayerManager::finished_callback reached end")
+            log.info("PlayerManager::finished_callback reached end")
             self.send_timeline_stopped(True)
         self.pause_ignore = False
 
@@ -846,20 +857,20 @@ class PlayerManager(object):
         sub_uid = self._video.sid
 
         if audio_uid is not None and not self._video.is_transcode:
-            log.debug("PlayerManager::play selecting audio stream index=%s" % audio_uid)
+            log.info("PlayerManager::play selecting audio stream index=%s" % audio_uid)
             self._player.audio = self._video.audio_seq[audio_uid]
 
         if sub_uid is None or sub_uid == -1:
-            log.debug("PlayerManager::play selecting subtitle stream (none)")
+            log.info("PlayerManager::play selecting subtitle stream (none)")
             self._player.sub = "no"
         else:
-            log.debug(
+            log.info(
                 "PlayerManager::play selecting subtitle stream index=%s" % sub_uid
             )
             if sub_uid in self._video.subtitle_seq:
                 self._player.sub = self._video.subtitle_seq[sub_uid]
             elif sub_uid in self._video.subtitle_url:
-                log.debug(
+                log.info(
                     "PlayerManager::play selecting external subtitle id=%s" % sub_uid
                 )
                 self.load_external_sub(sub_uid)
@@ -882,12 +893,12 @@ class PlayerManager(object):
             try:
                 sub_url = self._video.subtitle_url[sub_id]
                 if settings.log_decisions:
-                    log.debug("Load External Subtitle: {0}".format(sub_url))
+                    log.info("Load External Subtitle: {0}".format(sub_url))
                 self._player.sub_add(sub_url)
                 self.external_subtitles[sub_id] = self._player.sub
                 self.external_subtitles_rev[self._player.sub] = sub_id
             except SystemError:
-                log.debug("PlayerManager::could not load external subtitle")
+                log.info("PlayerManager::could not load external subtitle")
 
     @synchronous("_lock")
     def toggle_fullscreen(self):
